==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/install_24_TTC_USB.sh <==
#!/bin/bash
#
#
#  Install script for generic USART support 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="500_ttc_usb"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

MAIN_OBJS += ttc_usb.o

ifdef TARGET_ARCHITECTURE_STM32
  MAIN_OBJS += stm32_usb.o
endif

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Architecture independent support for Universal Synchronous Asynchronous Serial Receiver Transmitter (USART)"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_Additionals/${Name}_*

Architecture=""
if [ -e extensions/activate.250_stm_std_peripherals__usart.sh ]; then
  activate.250_stm_std_peripherals__usart.sh QUIET \"\$0\"
  Architecture="stm32"
fi

if [ "\$Architecture" != "" ]; then
  activate.500_ttc_interrupt.sh QUIET \"\$0\"
  activate.500_ttc_gpio.sh QUIET \"\$0\"
  activate.500_ttc_queue.sh QUIET \"\$0\"
  activate.500_ttc_task.sh QUIET \"\$0\"
  activate.500_ttc_string.sh QUIET \"\$0\"
  
  # create links into extensions.active/
  createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET
else
  echo "$0 - ERROR: no supported architecture found!"
fi

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}

  echo "Installed successfully: $Name"

  

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/ToolChain/install_24_TTC_USB.sh <==
#!/bin/bash
#
#
#  Install script for generic USART support 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh
checkUserRoot "$1" "$2"

StartPath="`pwd`"
INSTALLPATH="500_ttc_usb"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>$ExtensionMakeFile # variable set by createExtensionMakefileHead() 

MAIN_OBJS += ttc_usb.o

ifdef TARGET_ARCHITECTURE_STM32
  MAIN_OBJS += stm32_usb.o
endif

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  createActivateScriptHead $Name ../extensions/ "$0" "Architecture independent support for Universal Synchronous Asynchronous Serial Receiver Transmitter (USART)" #{
  cat <<END_OF_ACTIVATE >>$ActivateScriptFile
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_Additionals/${Name}_*

Architecture=""
if [ -e extensions/activate.250_stm_std_peripherals__usart.sh ]; then
  activate.250_stm_std_peripherals__usart.sh QUIET \"\$0\"
  Architecture="stm32"
fi

if [ "\$Architecture" != "" ]; then
  activate.500_ttc_interrupt.sh QUIET \"\$0\"
  activate.500_ttc_gpio.sh QUIET \"\$0\"
  activate.500_ttc_queue.sh QUIET \"\$0\"
  activate.500_ttc_task.sh QUIET \"\$0\"
  activate.500_ttc_string.sh QUIET \"\$0\"
  
  # create links into extensions.active/
  createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET
else
  echo "$0 - ERROR: no supported architecture found!"
fi

END_OF_ACTIVATE
  createActivateScriptTail $Name ../extensions/
  #}

  echo "Installed successfully: $Name"

  

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

cd "$StartPath"
applyTargetUserAndGroup "$INSTALLPATH"

exit 0
